@@ -1,7 +1,7 @@
 ;;;
 ;;; os.windows - Windows-specific procedures
 ;;;
-;;;   Copyright (c) 2010-2016  Shiro Kawai  <shiro@acm.org>
+;;;   Copyright (c) 2010-2020  Shiro Kawai  <shiro@acm.org>
 ;;;
 ;;;   Redistribution and use in source and binary forms, with or without
 ;;;   modification, are permitted provided that the following conditions
@@ -35,6 +35,9 @@
 
 (define-module os.windows
   (export
+   ;; Fileapi
+   sys-get-disk-free-space-ex
+
    ;; MessageBox
    MB_ABORTRETRYIGNORE MB_CANCELTRYCONTINUE MB_HELP MB_OK MB_OKCANCEL
    MB_RETRYCANCEL MB_YESNO MB_YESNOCANCEL
